@@ -49,7 +49,7 @@ UseBuilder::UseBuilder(PythonEditorIntegrator* editor, QVector<IndexedString> ig
 
 DUContext* UseBuilder::contextAtOrCurrent(const CursorInRevision& pos)
 {
-    DUContext* context = 0;
+    DUContext* context = nullptr;
     {
         DUChainReadLocker lock;
         context = topContext()->findContextAt(pos, true);
@@ -61,30 +61,31 @@ DUContext* UseBuilder::contextAtOrCurrent(const CursorInRevision& pos)
 }
 
 void UseBuilder::useHiddenMethod(ExpressionAst* value, Declaration* function) {
+    if ( !function || function->topContext() == Helper::getDocumentationFileContext() ) {
+        // Don't add a use for e.g. `list.__getitem__` in `foo[0]`, no-one cares.
+        return;
+    }
     RangeInRevision useRange;
     // TODO fixme! this does not necessarily use the opening bracket as it should
     useRange.start = CursorInRevision(value->endLine, value->endCol + 1);
     useRange.end = CursorInRevision(value->endLine, value->endCol + 2);
     if ( function && function->isFunctionDeclaration() ) {
-        UseBuilderBase::newUse(value, useRange, DeclarationPointer(function));
+        UseBuilderBase::newUse(useRange, DeclarationPointer(function));
     }
 }
 
 void UseBuilder::visitName(NameAst* node)
 {
     DUContext* context = contextAtOrCurrent(editorFindPositionSafe(node));
-    Declaration* declaration = Helper::declarationForName(identifierForNode(node->identifier),
-                                                          editorFindRange(node, node),
+    Declaration* declaration = Helper::declarationForName(node, editorFindPositionSafe(node),
                                                           DUChainPointer<const DUContext>(context));
 
-    static const QStringList keywords = {"None", "True", "False"};
-
     Q_ASSERT(node->identifier);
     RangeInRevision useRange = rangeForNode(node->identifier, true);
 
     if ( declaration && declaration->range() == useRange ) return;
 
-    if ( ! declaration && ! keywords.contains(node->identifier->value) && m_errorReportingEnabled ) {
+    if ( ! declaration && m_errorReportingEnabled ) {
         if ( ! m_ignoreVariables.contains(IndexedString(node->identifier->value)) ) {
             KDevelop::Problem *p = new KDevelop::Problem();
             p->setFinalLocation(DocumentRange(currentlyParsedDocument(), useRange.castToSimpleRange())); // TODO ok?
@@ -98,7 +99,7 @@ void UseBuilder::visitName(NameAst* node)
             }
         }
     }
-    UseBuilderBase::newUse(node, useRange, DeclarationPointer(declaration));
+    UseBuilderBase::newUse(useRange, DeclarationPointer(declaration));
 }
 
 void UseBuilder::visitCall(CallAst* node)
@@ -118,9 +119,7 @@ void UseBuilder::visitCall(CallAst* node)
 
 void UseBuilder::visitAttribute(AttributeAst* node)
 {
-    qCDebug(KDEV_PYTHON_DUCHAIN) << "VisitAttribute start";
     UseBuilderBase::visitAttribute(node);
-    qCDebug(KDEV_PYTHON_DUCHAIN) << "Visit Attribute base end";
 
     DUContext* context = contextAtOrCurrent(editorFindPositionSafe(node));
     ExpressionVisitor v(context);
@@ -143,7 +142,7 @@ void UseBuilder::visitAttribute(AttributeAst* node)
         ProblemPointer ptr(p);
         topContext()->addProblem(ptr);
     }
-    UseBuilderBase::newUse(node, useRange, declaration);
+    UseBuilderBase::newUse(useRange, declaration);
 }
 
 void UseBuilder::visitSubscript(SubscriptAst* node) {
